@@ -9,7 +9,7 @@ import os
 from glob import glob
 from typing import Any
 
-import json5  # type:ignore[import-untyped]
+import json5
 from jsonschema import Draft7Validator as Validator
 from jsonschema import ValidationError
 from jupyter_server import _tz as tz
@@ -448,11 +448,15 @@ class SchemaHandler(APIHandler):
         schemas_dir: str,
         settings_dir: str,
         labextensions_path: list[str] | None,
+        overrides: dict[str, Any] | None = None,
         **kwargs: Any,
     ) -> None:
         """Initialize the handler."""
         super().initialize(**kwargs)
-        self.overrides, error = _get_overrides(app_settings_dir)
+        error = None
+        if not overrides:
+            overrides, error = _get_overrides(app_settings_dir)
+        self.overrides = overrides
         self.app_settings_dir = app_settings_dir
         self.schemas_dir = schemas_dir
         self.settings_dir = settings_dir
